PercentFormatIntegerConstructor

Trait PercentFormatIntegerConstructor 

pub trait PercentFormatIntegerConstructor {
    // Required methods
    fn percent(self) -> Percent;
    fn ppm(self) -> Percent;
}
Percent formatted value from integer constructor trait.

Required Methods

fn percent(self) -> Percent

Builds a Percent formatted value from self interpreted as a percent.

fn ppm(self) -> Percent

Builds a Percent formatted value from self interpreted as parts per million.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PercentFormatIntegerConstructor for u32

Implementors