PluginFeatureExtManual

Trait PluginFeatureExtManual 

pub trait PluginFeatureExtManual: IsA<PluginFeature> + 'static {
    // Provided methods
    fn rank(&self) -> Rank { ... }
    fn set_rank(&self, rank: Rank) { ... }
    fn load(&self) -> Result<Self, BoolError> { ... }
}

Provided Methods

fn rank(&self) -> Rank

Gets the rank of a plugin feature.

Returns

The rank of the feature

fn set_rank(&self, rank: Rank)

Specifies a rank for a plugin feature, so that autoplugging uses the most appropriate feature.

rank

rank value - higher number means more priority rank

fn load(&self) -> Result<Self, BoolError>

GstPluginFeature *loaded_feature;

loaded_feature = gst_plugin_feature_load (feature); // presumably, we’re no longer interested in the potentially-unloaded feature gst_object_unref (feature); feature = loaded_feature; ]|

Returns

a reference to the loaded feature, or None on error

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors