StaticCaps

Struct StaticCaps 

pub struct StaticCaps(/* private fields */);
Data structure to initialize Caps from a string description usually used in conjunction with GST_STATIC_CAPS() and get() to instantiate a Caps.

Implementations

Source

impl StaticCaps

pub fn get(&self) -> Caps

Converts a StaticCaps to a Caps.

Returns

a pointer to the Caps. Since the core holds an additional ref to the returned caps, use [Caps::make_writable()][crate::Caps::make_writable()] on the returned caps to modify it.