AudioInfo

Struct AudioInfo 

pub struct AudioInfo(/* private fields */);
Information describing audio properties. This information can be filled in from GstCaps with from_caps().

Use the provided macros to access the info in this structure.

Implementations

Source

impl AudioInfo

pub fn builder<'a>( format: AudioFormat, rate: u32, channels: u32, ) -> AudioInfoBuilder<'a>

pub fn builder_from_info(info: &AudioInfo) -> AudioInfoBuilder<'_>

pub fn is_valid(&self) -> bool

pub fn from_caps(caps: &CapsRef) -> Result<Self, BoolError>

Parse caps to generate a AudioInfo.

caps

a gst::Caps

Returns

A AudioInfo, or None if caps couldn’t be parsed

pub fn to_caps(&self) -> Result<Caps, BoolError>

Convert the values of self into a gst::Caps.

Returns

the new gst::Caps containing the info of self.

pub fn convert<U: SpecificFormattedValueFullRange>( &self, src_val: impl FormattedValue, ) -> Option<U>

Converts among various gst::Format types. This function handles GST_FORMAT_BYTES, GST_FORMAT_TIME, and GST_FORMAT_DEFAULT. For raw audio, GST_FORMAT_DEFAULT corresponds to audio frames. This function can be used to handle pad queries of the type GST_QUERY_CONVERT.

src_fmt

gst::Format of the src_val

src_val

value to convert

dest_fmt

gst::Format of the dest_val

Returns

TRUE if the conversion was successful.

dest_val

pointer to destination value

pub fn convert_generic( &self, src_val: impl FormattedValue, dest_fmt: Format, ) -> Option<GenericFormattedValue>

pub fn format(&self) -> AudioFormat

pub fn format_info(&self) -> AudioFormatInfo

pub fn layout(&self) -> AudioLayout

pub fn flags(&self) -> AudioFlags

pub fn rate(&self) -> u32

pub fn channels(&self) -> u32

pub fn bpf(&self) -> u32

pub fn bps(&self) -> u32

pub fn depth(&self) -> u32

pub fn width(&self) -> u32

pub fn endianness(&self) -> AudioEndianness

pub fn is_big_endian(&self) -> bool

pub fn is_little_endian(&self) -> bool

pub fn is_float(&self) -> bool

pub fn is_integer(&self) -> bool

pub fn is_signed(&self) -> bool

pub fn positions(&self) -> Option<&[AudioChannelPosition]>

pub fn is_unpositioned(&self) -> bool