TimedValueControlSourceExt

Trait TimedValueControlSourceExt 

pub trait TimedValueControlSourceExt: IsA<TimedValueControlSource> + 'static {
    // Provided methods
    fn count(&self) -> i32 { ... }
    fn set(&self, timestamp: ClockTime, value: f64) -> bool { ... }
    fn unset(&self, timestamp: ClockTime) -> bool { ... }
    fn unset_all(&self) { ... }
    fn connect_value_added<F: Fn(&Self, &ControlPoint) + Send + Sync + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_value_changed<F: Fn(&Self, &ControlPoint) + Send + Sync + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_value_removed<F: Fn(&Self, &ControlPoint) + Send + Sync + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
}
Provided Methods

fn count(&self) -> i32

Get the number of control points that are set.

Returns

the number of control points that are set.

fn set(&self, timestamp: ClockTime, value: f64) -> bool

Set the value of given controller-handled property at a certain time.

timestamp

the time the control-change is scheduled for

value

the control-value

Returns

FALSE if the values couldn’t be set, TRUE otherwise.

fn unset(&self, timestamp: ClockTime) -> bool

Used to remove the value of given controller-handled property at a certain time.

timestamp

the time the control-change should be removed from

Returns

FALSE if the value couldn’t be unset (i.e. not found, TRUE otherwise.

fn unset_all(&self)

Used to remove all time-stamped values of given controller-handled property

fn connect_value_added<F: Fn(&Self, &ControlPoint) + Send + Sync + 'static>( &self, f: F, ) -> SignalHandlerId

Emitted right after the new value has been added to self_

timed_value

The newly added GstTimedValue

fn connect_value_changed<F: Fn(&Self, &ControlPoint) + Send + Sync + 'static>( &self, f: F, ) -> SignalHandlerId

Emitted right after the new value has been set on timed_signals

timed_value

The GstTimedValue where the value changed

fn connect_value_removed<F: Fn(&Self, &ControlPoint) + Send + Sync + 'static>( &self, f: F, ) -> SignalHandlerId

Emitted when timed_value is removed from self_

timed_value

The removed GstTimedValue

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors