Struct Marker List
Source pub struct MarkerList { /* private fields */ }Expand description
A Marker can be colored by setting the GES_META_MARKER_COLOR meta.
Properties
flags
Flags indicating how markers on the list should be treated.
Readable | Writeable | Construct
Signals
marker-added
Will be emitted after the marker was added to the marker-list.
marker-moved
Will be emitted after the marker was moved to.
marker-removed
Will be emitted after the marker was removed the marker-list.
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl MarkerList
impl MarkerList
Sourcepub fn new() -> MarkerList
pub fn new() -> MarkerList
Sourcepub fn add(&self, position: impl Into<Option<ClockTime>>) -> Marker
👎Deprecated: Since 1.30
pub fn add(&self, position: impl Into<Option<ClockTime>>) -> Marker
Since 1.30
Deprecated since 1.30
Use add_full() instead for MT-safety.
position
The position of the new marker
Returns
The newly-added marker, the list keeps ownership of the marker
Sourcepub fn flags(&self) -> MarkerFlags
pub fn flags(&self) -> MarkerFlags
Flags indicating how markers on the list should be treated.
Sourcepub fn set_flags(&self, flags: MarkerFlags)
pub fn set_flags(&self, flags: MarkerFlags)
Flags indicating how markers on the list should be treated.
Sourcepub fn connect_marker_added<F: Fn(&Self, u64, &Marker) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_marker_added<F: Fn(&Self, u64, &Marker) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_marker_moved<F: Fn(&Self, u64, u64, &Marker) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_marker_moved<F: Fn(&Self, u64, u64, &Marker) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_marker_removed<F: Fn(&Self, &Marker) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_marker_removed<F: Fn(&Self, &Marker) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_flags_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId