GLBufferPoolExt

Trait GLBufferPoolExt 

pub trait GLBufferPoolExt: IsA<GLBufferPool> + 'static {
    // Provided method
    fn gl_allocation_params(&self) -> Option<GLAllocationParams> { ... }
}
Trait containing all GLBufferPool methods.

Implementors

GLBufferPool

Provided Methods

fn gl_allocation_params(&self) -> Option<GLAllocationParams>

The returned GLAllocationParams will by None before the first successful call to BufferPoolExtManual::set_config(). Subsequent successful calls to BufferPoolExtManual::set_config() will cause this function to return a new GLAllocationParams which may or may not contain the same information.

Returns

a copy of the GLAllocationParams being used by the self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors