GLMemoryPBO

Struct GLMemoryPBO 

pub struct GLMemoryPBO { /* private fields */ }

Implementations

Methods from Deref<Target = GLMemoryPBORef>

Methods from Deref<Target = GLMemoryRef>

pub fn as_ptr(&self) -> *const GstGLMemory

pub fn as_mut_ptr(&self) -> *mut GstGLMemory

pub fn copy(&self) -> GLMemory

pub fn upcast_ref(&self) -> &MiniObjectRef

pub fn upcast_mut(&mut self) -> &mut MiniObjectRef

pub fn mark_may_be_leaked(&mut self)

pub fn upcast_memory_ref<M>(&self) -> &M::RefType

pub fn upcast_memory_mut<M>(&mut self) -> &mut M::RefType

pub unsafe fn copy_into( &self, tex_id: u32, target: GLTextureTarget, tex_format: GLFormat, width: i32, height: i32, ) -> Result<(), LoggableError>

Safety

tex_id is not validated to be a valid GL texture, which may lead to undefined behaviour.

pub unsafe fn copy_teximage( &self, tex_id: u32, out_target: GLTextureTarget, out_tex_format: GLFormat, out_width: i32, out_height: i32, ) -> Result<(), LoggableError>

Safety

tex_id is not validated to be a valid GL texture, which may lead to undefined behaviour.

pub fn texture_format(&self) -> GLFormat

pub fn texture_height(&self) -> i32

pub fn texture_id(&self) -> u32

pub fn texture_target(&self) -> GLTextureTarget

pub fn texture_width(&self) -> i32

Methods from Deref<Target = GLBaseMemoryRef>

pub fn as_ptr(&self) -> *const GstGLBaseMemory

pub fn as_mut_ptr(&self) -> *mut GstGLBaseMemory

pub fn copy(&self) -> GLBaseMemory

pub fn upcast_ref(&self) -> &MiniObjectRef

pub fn upcast_mut(&mut self) -> &mut MiniObjectRef

pub fn mark_may_be_leaked(&mut self)

pub fn upcast_memory_ref<M>(&self) -> &M::RefType

pub fn upcast_memory_mut<M>(&mut self) -> &mut M::RefType

pub unsafe fn memcpy( &self, dest: &mut GLBaseMemory, offset: isize, size: isize, ) -> Result<(), BoolError>

pub fn context(&self) -> &GLContext

Methods from Deref<Target = MemoryRef>

pub fn as_ptr(&self) -> *const GstMemory

pub fn as_mut_ptr(&self) -> *mut GstMemory

pub fn copy(&self) -> Memory

pub fn upcast_ref(&self) -> &MiniObjectRef

pub fn upcast_mut(&mut self) -> &mut MiniObjectRef

pub fn mark_may_be_leaked(&mut self)

pub fn allocator(&self) -> Option<&Allocator>

pub fn parent(&self) -> Option<&MemoryRef>

pub fn maxsize(&self) -> usize

pub fn align(&self) -> usize

pub fn offset(&self) -> usize

pub fn size(&self) -> usize

pub fn sizes(&self) -> (usize, usize, usize)

pub fn flags(&self) -> MemoryFlags

pub fn copy_range(&self, range: impl RangeBounds<usize>) -> Memory

pub fn copy_range_maxsize(&self, range: impl RangeBounds<usize>) -> Memory

pub fn is_span(&self, mem2: &MemoryRef) -> Option<usize>

pub fn is_type(&self, mem_type: impl IntoGStr) -> bool

pub fn map_readable(&self) -> Result<MemoryMap<'_, Readable>, BoolError>

pub fn map_writable(&mut self) -> Result<MemoryMap<'_, Writable>, BoolError>

pub fn share(&self, range: impl RangeBounds<usize>) -> Memory

pub fn share_maxsize(&self, range: impl RangeBounds<usize>) -> Memory

pub fn resize(&mut self, range: impl RangeBounds<usize>)

pub fn resize_maxsize(&mut self, range: impl RangeBounds<usize>)

pub fn dump(&self) -> Dump<'_>

pub fn dump_range(&self, range: impl RangeBounds<usize>) -> Dump<'_>

pub fn is_memory_type<M>(&self) -> bool

pub fn downcast_memory_ref<M>(&self) -> Option<&<M as IsMiniObject>::RefType>

pub fn downcast_memory_mut<M>( &mut self, ) -> Option<&mut <M as IsMiniObject>::RefType>