codec_utils_h264_get_level_limits

Function codec_utils_h264_get_level_limits 

pub fn codec_utils_h264_get_level_limits(
    width: i32,
    height: i32,
    fps_n: i32,
    fps_d: i32,
    bitrate: u32,
    max_dec_frame_buffering: u32,
    profile_idc: u8,
) -> Option<H264LevelLimits>
Finds the minimum H.264 level that can handle the given video parameters based on the constraints defined in H.264 specification Annex A.

width

the video width in pixels

height

the video height in pixels

fps_n

the video frame rate numerator

fps_d

the video frame rate denominator

bitrate

the video bitrate in bits per second (0 if unknown)

max_dec_frame_buffering

the max size of DPB (0 if unknown)

profile_idc

the H.264 profile idc value (e.g., 66 for Baseline, 77 for Main, 100 for High)

Returns

the GstH264LevelLimits for the minimum level matching the parameters, or None if no suitable level is found.