description

Function description 

pub fn description(license_ref: &str) -> Option<GString>
Get the description of a license, which is a translated description of the license’s main features.

license_ref

a license reference string in form of a URI, e.g. “http://creativecommons.org/licenses/by-nc-nd/2.0/”

Returns

the description of the license, or NULL if the license is unknown or a description is not available.