version

Function version 

pub fn version(license_ref: &str) -> Option<GString>
Get the version of a license.

license_ref

a license reference string in form of a URI, e.g. “http://creativecommons.org/licenses/by-nc-nd/2.0/”

Returns

the version of the license, or NULL if the license is not known or has no version