TracingTracerImpl

Trait TracingTracerImpl 

pub trait TracingTracerImpl: TracerImpl { }
Trait for implementing custom tracers that extend TracingTracer.

Implement this trait to create tracers that build upon the GStreamer-tracing integration, such as tracers that use specific tracing subscribers.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors