NavigationCommand

Enum NavigationCommand 

#[non_exhaustive]
pub enum NavigationCommand {
Show 15 variants Invalid, Menu1, Menu2, Menu3, Menu4, Menu5, Menu6, Menu7, Left, Right, Up, Down, Activate, PrevAngle, NextAngle,
}
A set of commands that may be issued to an element providing the Navigation interface. The available commands can be queried via the gst_navigation_query_new_commands() query.

For convenience in handling DVD navigation, the MENU commands are aliased as: GST_NAVIGATION_COMMAND_DVD_MENU = Menu1 GST_NAVIGATION_COMMAND_DVD_TITLE_MENU = Menu2 GST_NAVIGATION_COMMAND_DVD_ROOT_MENU = Menu3 GST_NAVIGATION_COMMAND_DVD_SUBPICTURE_MENU = Menu4 GST_NAVIGATION_COMMAND_DVD_AUDIO_MENU = Menu5 GST_NAVIGATION_COMMAND_DVD_ANGLE_MENU = Menu6 GST_NAVIGATION_COMMAND_DVD_CHAPTER_MENU = Menu7

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Invalid

An invalid command entry



Menu1

Execute navigation menu command 1. For DVD, this enters the DVD root menu, or exits back to the title from the menu.



Menu2

Execute navigation menu command 2. For DVD, this jumps to the DVD title menu.



Menu3

Execute navigation menu command 3. For DVD, this jumps into the DVD root menu.



Menu4

Execute navigation menu command 4. For DVD, this jumps to the Subpicture menu.



Menu5

Execute navigation menu command 5. For DVD, the jumps to the audio menu.



Menu6

Execute navigation menu command 6. For DVD, this jumps to the angles menu.



Menu7

Execute navigation menu command 7. For DVD, this jumps to the chapter menu.



Left

Select the next button to the left in a menu, if such a button exists.



Right

Select the next button to the right in a menu, if such a button exists.



Up

Select the button above the current one in a menu, if such a button exists.



Down

Select the button below the current one in a menu, if such a button exists.



Activate

Activate (click) the currently selected button in a menu, if such a button exists.



PrevAngle

Switch to the previous angle in a multiangle feature.



NextAngle

Switch to the next angle in a multiangle feature.