Enum Video Interlace Mode
Source #[non_exhaustive]pub enum VideoInterlaceMode {
Progressive,
Interleaved,
Mixed,
Fields,
Alternate,
}Expand description
The possible values of the VideoInterlaceMode describing the interlace
mode of the stream.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Progressive
all frames are progressive
Interleaved
2 fields are interleaved in one video frame. Extra buffer flags describe the field order.
Mixed
frames contains both interlaced and progressive video, the buffer flags describe the frame and fields.
Fields
- the fields of view N can be found at frame ID (N * 2) and (N * 2) + 1. Each field has only half the amount of lines as noted in the height property. This mode requires multiple GstVideoMeta metadata to describe the fields.
Alternate
1 field is stored in one buffer,
GST_VIDEO_BUFFER_FLAG_TF or GST_VIDEO_BUFFER_FLAG_BF indicates if
the buffer is carrying the top or bottom field, respectively. The top and
bottom buffers must alternate in the pipeline, with this mode
(Since: 1.16).
Implementations
Sourceimpl VideoInterlaceMode
impl VideoInterlaceMode
pub fn from_string(mode: &str) -> VideoInterlaceMode
pub fn to_str<'a>(self) -> &'a GStr