VideoTransferFunction

Enum VideoTransferFunction 

#[non_exhaustive]
pub enum VideoTransferFunction {
Show 17 variants Unknown, Gamma10, Gamma18, Gamma20, Gamma22, Bt709, Smpte240m, Srgb, Gamma28, Log100, Log316, Bt202012, Adobergb, Bt202010, Smpte2084, AribStdB67, Bt601,
}
The video transfer function defines the formula for converting between non-linear RGB (R’G’B’) and linear RGB

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown

unknown transfer function



Gamma10

linear RGB, gamma 1.0 curve



Gamma18

Gamma 1.8 curve



Gamma20

Gamma 2.0 curve



Gamma22

Gamma 2.2 curve



Bt709

Gamma 2.2 curve with a linear segment in the lower range, also ITU-R BT470M / ITU-R BT1700 625 PAL & SECAM / ITU-R BT1361



Smpte240m

Gamma 2.2 curve with a linear segment in the lower range



Srgb

Gamma 2.4 curve with a linear segment in the lower range. IEC 61966-2-1 (sRGB or sYCC)



Gamma28

Gamma 2.8 curve, also ITU-R BT470BG



Log100

Logarithmic transfer characteristic 100:1 range



Log316

Logarithmic transfer characteristic 316.22777:1 range (100 * sqrt(10) : 1)



Bt202012

Gamma 2.2 curve with a linear segment in the lower range. Used for BT.2020 with 12 bits per component. Since: 1.6



Adobergb

Gamma 2.19921875. Since: 1.8



Bt202010

Rec. ITU-R BT.2020-2 with 10 bits per component. (functionally the same as the values GST_VIDEO_TRANSFER_BT709 and GST_VIDEO_TRANSFER_BT601). Since: 1.18



Smpte2084

SMPTE ST 2084 for 10, 12, 14, and 16-bit systems. Known as perceptual quantization (PQ) Since: 1.18



AribStdB67

Association of Radio Industries and Businesses (ARIB) STD-B67 and Rec. ITU-R BT.2100-1 hybrid loggamma (HLG) system Since: 1.18



Bt601

also known as SMPTE170M / ITU-R BT1358 525 or 625 / ITU-R BT1700 NTSC

Implementations

Source

impl VideoTransferFunction

pub fn decode(self, val: f64) -> f64

pub fn encode(self, val: f64) -> f64

pub fn from_iso(value: u32) -> VideoTransferFunction

pub fn is_equivalent( self, from_bpp: u32, to_func: VideoTransferFunction, to_bpp: u32, ) -> bool

pub fn to_iso(self) -> u32