VideoInfoDmaDrm

Struct VideoInfoDmaDrm 

pub struct VideoInfoDmaDrm(/* private fields */);
Information describing a DMABuf image properties. It wraps VideoInfo and adds DRM information such as drm-fourcc and drm-modifier, required for negotiation and mapping.

Implementations

Source

impl VideoInfoDmaDrm

pub fn new(info: VideoInfo, fourcc: u32, modifier: u64) -> VideoInfoDmaDrm

Allocate a new VideoInfoDmaDrm that is also initialized with [init()][Self::init()].

Returns

a new VideoInfoDmaDrm. Free it with gst_video_info_dma_drm_free().

pub fn is_valid(&self) -> bool

pub fn from_caps(caps: &CapsRef) -> Result<Self, BoolError>

Parse caps to generate a VideoInfoDmaDrm. Please note that the caps should be a dma drm caps. The gst_video_is_dma_drm_caps() can be used to verify it before calling this function.

caps

a gst::Caps

Returns

A VideoInfoDmaDrm, or None if caps couldn’t be parsed.

pub fn to_caps(&self) -> Result<Caps, BoolError>

Convert the values of self into a gst::Caps. Please note that the caps returned will be a dma drm caps which sets format field to DMA_DRM, and contains a new drm-format field. The value of drm-format field is composed of a drm fourcc and a modifier, such as NV12:0x0100000000000002.

Returns

a new gst::Caps containing the info in self.

pub fn from_video_info( video_info: &VideoInfo, modifier: u64, ) -> Result<Self, BoolError>

Fills drm_info if info’s format has a valid drm format and modifier is also valid

info

a VideoInfo

modifier

the associated modifier value.

Returns

true if drm_info is filled correctly.

drm_info

VideoInfoDmaDrm

pub fn to_video_info(&self) -> Result<VideoInfo, BoolError>

Convert the VideoInfoDmaDrm into a traditional VideoInfo with recognized video format. For DMA kind memory, the non linear DMA format should be recognized as VideoFormat::DmaDrm. This helper function sets info’s video format into the default value according to self’s drm_fourcc field.

Returns

true if info is converted correctly.

info

VideoInfo

pub fn fourcc(&self) -> u32

pub fn modifier(&self) -> u64

Methods from Deref<Target = VideoInfo>

pub fn is_valid(&self) -> bool

pub fn to_caps(&self) -> Result<Caps, BoolError>

Convert the values of self into a gst::Caps.

Returns

a new gst::Caps containing the info of self.

pub fn format(&self) -> VideoFormat

pub fn format_info(&self) -> VideoFormatInfo

pub fn name<'a>(&self) -> &'a str

pub fn width(&self) -> u32

pub fn height(&self) -> u32

pub fn field_height(&self) -> u32

pub fn interlace_mode(&self) -> VideoInterlaceMode

pub fn flags(&self) -> VideoFlags

pub fn size(&self) -> usize

pub fn views(&self) -> u32

pub fn chroma_site(&self) -> VideoChromaSite

pub fn colorimetry(&self) -> VideoColorimetry

pub fn comp_depth(&self, component: u8) -> u32

pub fn comp_height(&self, component: u8) -> u32

pub fn comp_width(&self, component: u8) -> u32

pub fn comp_offset(&self, component: u8) -> usize

pub fn comp_plane(&self, component: u8) -> u32

pub fn comp_poffset(&self, component: u8) -> u32

pub fn comp_pstride(&self, component: u8) -> i32

pub fn comp_stride(&self, component: u8) -> i32

pub fn par(&self) -> Fraction

pub fn fps(&self) -> Fraction

pub fn field_rate(&self) -> Fraction

pub fn offset(&self) -> &[usize]

pub fn stride(&self) -> &[i32]

pub fn multiview_mode(&self) -> VideoMultiviewMode

pub fn multiview_flags(&self) -> VideoMultiviewFlags

pub fn field_order(&self) -> VideoFieldOrder

pub fn has_alpha(&self) -> bool

pub fn is_gray(&self) -> bool

pub fn is_rgb(&self) -> bool

pub fn is_yuv(&self) -> bool

pub fn is_interlaced(&self) -> bool

pub fn n_planes(&self) -> u32

pub fn n_components(&self) -> u32

pub fn convert<U: SpecificFormattedValueFullRange>( &self, src_val: impl FormattedValue, ) -> Option<U>

Converts among various gst::Format types. This function handles GST_FORMAT_BYTES, GST_FORMAT_TIME, and GST_FORMAT_DEFAULT. For raw video, GST_FORMAT_DEFAULT corresponds to video frames. This function can be used to handle pad queries of the type GST_QUERY_CONVERT.

src_format

gst::Format of the src_value

src_value

value to convert

dest_format

gst::Format of the dest_value

Returns

TRUE if the conversion was successful.

dest_value

pointer to destination value

pub fn convert_generic( &self, src_val: impl FormattedValue, dest_fmt: Format, ) -> Option<GenericFormattedValue>

pub fn range_offsets(&self, range: VideoColorRange) -> ([i32; 4], [i32; 4])