Trait RTSP Address Pool Ext
Source pub trait RTSPAddressPoolExt: IsA<RTSPAddressPool> + 'static {
// Provided methods
fn acquire_address(
&self,
flags: RTSPAddressFlags,
n_ports: i32,
) -> Result<RTSPAddress, BoolError> { ... }
fn add_range(
&self,
min_address: &str,
max_address: &str,
min_port: u16,
max_port: u16,
ttl: u8,
) -> Result<(), BoolError> { ... }
fn clear(&self) { ... }
fn dump(&self) { ... }
fn has_unicast_addresses(&self) -> bool { ... }
}Expand description
Provided Methods
Sourcefn acquire_address(
&self,
flags: RTSPAddressFlags,
n_ports: i32,
) -> Result<RTSPAddress, BoolError>
fn acquire_address( &self, flags: RTSPAddressFlags, n_ports: i32, ) -> Result<RTSPAddress, BoolError>
Take an address and ports from self. flags can be used to control the
allocation. n_ports consecutive ports will be allocated of which the first
one can be found in port.
flags
flags
n_ports
the amount of ports
Returns
a RTSPAddress that should be freed with
gst_rtsp_address_free after use or None when no address could be
acquired.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".