Function nick
Source pub fn nick(license_ref: &str) -> Option<GString>
Get the nick name of a license, which is a short (untranslated) string
such as e.g. “CC BY-NC-ND 2.0 UK”.
license_ref
a license reference string in form of a URI,
e.g. “http://creativecommons.org/licenses/by-nc-nd/2.0/”
Returns
the nick name of the license, or NULL if the license is unknown